Trait dbkit_engine::operation::Operation [] [src]

pub trait Operation<'a> {
    fn bind<'b: 'a>(&self, &'b Allocator) -> Result<Box<Cursor<'a> + 'a>, DBError>;
}

Operation is the basic building model of a query.

Operations are built together into a tree of Operation that represent the flow of rows from one relational Operation into another.

Required Methods

Convert operation AST a bound Cursor

Implementors