Module dbkit_engine::projector
[−]
[src]
Structs
| BoundProjector |
Typed checked and evaluated projector |
| BuildSingleSourceProjector | |
| MultiSourceProjector |
Projection for multi-input operation |
| SingleSourceProjector |
Projection for a single input operation |
Functions
| project_all_attributes |
Project all attributes without renaming them |
| project_by_name |
Project single argument from source by column name |
| project_by_position |
Project single argument from source by column position |