Struct dbkit_engine::table::Table [] [src]

pub struct Table<'alloc> {
    // some fields omitted
}

Abstraction on top of a Block for easy construction and modification of contained data.

The container assumes that all operations on the block are safe and schema type conforming. In case of errors it simply panics.

Methods

impl<'alloc> Table<'alloc>
[src]

Add a single row.

Take ownership of the contained Block.

This is done when the Table is complete and is going to be used elsewhere.

Get a mutable reference to the Table/Block column.

panics on out of bounds column

Set nul value for (col, row) in the currently allocated table space.

Set value for (col, row) in the currently allocated table space.