Struct dbkit_engine::table::TableAppender [] [src]

pub struct TableAppender<'alloc: 't, 't> {
    // some fields omitted
}

TableAppender is a convenient way to programmatically build a Table/Block.

TableAppender works on a row -> column basis. You first add a new row, then you fill up each of the columns in the row until you're ready for the next row (or done).

TableAppender assumes that the Table owns the Block. If the Table does not own the block (eg. it was been taken) then the use of TableAppender will result in a panic!

Methods

impl<'alloc, 't> TableAppender<'alloc, 't>
[src]

Result (error) of append operation

Takes the result (error) of the append operation

Append new row

Set column value to NUL and move onto the column to the right

Set column value and move onto the column to the right