Struct dbkit_engine::table::TableAppender
[−]
[src]
pub struct TableAppender<'alloc: 't, 't> {
// some fields omitted
}TableAppender is a convenient way to programmatically build a Table/Block.
TableAppender works on a row -> column basis. You first add a new row, then you fill up each
of the columns in the row until you're ready for the next row (or done).
TableAppender assumes that the Table owns the Block. If the Table does not own the block (eg.
it was been taken) then the use of TableAppender will result in a panic!
Methods
impl<'alloc, 't> TableAppender<'alloc, 't>[src]
fn new(table: &'t mut Table<'alloc>) -> TableAppender<'alloc, 't>
fn status(&self) -> Option<&DBError>
Result (error) of append operation
fn done(&mut self) -> Option<DBError>
Takes the result (error) of the append operation
fn add_row(self) -> TableAppender<'alloc, 't>
Append new row
fn set_null(self, value: bool) -> TableAppender<'alloc, 't>
Set column value to NUL and move onto the column to the right
fn set<T: ValueSetter>(self, value: T) -> TableAppender<'alloc, 't>
Set column value and move onto the column to the right